@@ -14,14 +14,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import _ast
+import ast
 
 import six
 
 from bandit.core import utils
 
 
-class Context():
+class Context(object):
     def __init__(self, context_object=None):
         '''Initialize the class with a context, empty dict otherwise
 
@@ -57,18 +57,19 @@ class Context():
         :return: A list of function args
         '''
         args = []
-        for arg in self._context['call'].args:
-            if hasattr(arg, 'attr'):
-                args.append(arg.attr)
-            else:
-                args.append(self._get_literal_value(arg))
+        if 'call' in self._context and hasattr(self._context['call'], 'args'):
+            for arg in self._context['call'].args:
+                if hasattr(arg, 'attr'):
+                    args.append(arg.attr)
+                else:
+                    args.append(self._get_literal_value(arg))
         return args
 
     @property
     def call_args_count(self):
         '''Get the number of args a function call has
 
-        :return: The number of args a function call has
+        :return: The number of args a function call has or None
         '''
         if 'call' in self._context and hasattr(self._context['call'], 'args'):
             return len(self._context['call'].args)
@@ -81,10 +82,7 @@ class Context():
 
         :return: The name (not FQ) of a function call
         '''
-        if 'name' in self._context:
-            return self._context['name']
-        else:
-            return None
+        return self._context.get('name')
 
     @property
     def call_function_name_qual(self):
@@ -92,10 +90,7 @@ class Context():
 
         :return: The FQ name of a function call
         '''
-        if 'qualname' in self._context:
-            return self._context['qualname']
-        else:
-            return None
+        return self._context.get('qualname')
 
     @property
     def call_keywords(self):
@@ -103,10 +98,8 @@ class Context():
 
         :return: A dictionary of keyword parameters for a call as strings
         '''
-        if (
-            'call' in self._context and
-            hasattr(self._context['call'], 'keywords')
-        ):
+        if ('call' in self._context and
+                hasattr(self._context['call'], 'keywords')):
             return_dict = {}
             for li in self._context['call'].keywords:
                 if hasattr(li.value, 'attr'):
@@ -123,10 +116,7 @@ class Context():
 
         :return: The raw AST node associated with the context
         '''
-        if 'node' in self._context:
-            return self._context['node']
-        else:
-            return None
+        return self._context.get('node')
 
     @property
     def string_val(self):
@@ -134,10 +124,7 @@ class Context():
 
         :return: value of a standalone unicode or string object
         '''
-        if 'str' in self._context:
-            return self._context['str']
-        else:
-            return None
+        return self._context.get('str')
 
     @property
     def bytes_val(self):
@@ -152,7 +139,7 @@ class Context():
         '''Get escaped value of the object.
 
         Turn the value of a string or bytes object into byte sequence with
-        unknown, control, and \ characters escaped.
+        unknown, control, and \\ characters escaped.
 
         This function should be used when looking for a known sequence in a
         potentially badly encoded string in the code.
@@ -176,10 +163,7 @@ class Context():
 
         :return: The raw AST for the current statement
         '''
-        if 'statement' in self._context:
-            return self._context['statement']
-        else:
-            return None
+        return self._context.get('statement')
 
     @property
     def function_def_defaults_qual(self):
@@ -188,7 +172,9 @@ class Context():
         :return: List of defaults
         '''
         defaults = []
-        if 'node' in self._context:
+        if ('node' in self._context and
+                hasattr(self._context['node'], 'args') and
+                hasattr(self._context['node'].args, 'defaults')):
             for default in self._context['node'].args.defaults:
                 defaults.append(utils.get_qual_attr(
                     default,
@@ -201,52 +187,54 @@ class Context():
         :param literal: The AST literal to convert
         :return: The value of the AST literal
         '''
-        if isinstance(literal, _ast.Num):
-            return literal.n
+        if isinstance(literal, ast.Num):
+            literal_value = literal.n
 
-        elif isinstance(literal, _ast.Str):
-            return literal.s
+        elif isinstance(literal, ast.Str):
+            literal_value = literal.s
 
-        elif isinstance(literal, _ast.List):
+        elif isinstance(literal, ast.List):
             return_list = list()
             for li in literal.elts:
                 return_list.append(self._get_literal_value(li))
-            return return_list
+            literal_value = return_list
 
-        elif isinstance(literal, _ast.Tuple):
+        elif isinstance(literal, ast.Tuple):
             return_tuple = tuple()
             for ti in literal.elts:
                 return_tuple = return_tuple + (self._get_literal_value(ti),)
-            return return_tuple
+            literal_value = return_tuple
 
-        elif isinstance(literal, _ast.Set):
+        elif isinstance(literal, ast.Set):
             return_set = set()
             for si in literal.elts:
                 return_set.add(self._get_literal_value(si))
-            return return_set
+            literal_value = return_set
 
-        elif isinstance(literal, _ast.Dict):
-            return dict(zip(literal.keys, literal.values))
+        elif isinstance(literal, ast.Dict):
+            literal_value = dict(zip(literal.keys, literal.values))
 
-        elif isinstance(literal, _ast.Ellipsis):
+        elif isinstance(literal, ast.Ellipsis):
             # what do we want to do with this?
-            pass
+            literal_value = None
 
-        elif isinstance(literal, _ast.Name):
-            return literal.id
+        elif isinstance(literal, ast.Name):
+            literal_value = literal.id
 
         # NOTE(sigmavirus24): NameConstants are only part of the AST in Python
         # 3. NameConstants tend to refer to things like True and False. This
         # prevents them from being re-assigned in Python 3.
-        elif six.PY3 and isinstance(literal, _ast.NameConstant):
-            return str(literal.value)
+        elif six.PY3 and isinstance(literal, ast.NameConstant):
+            literal_value = str(literal.value)
 
         # NOTE(sigmavirus24): Bytes are only part of the AST in Python 3
-        elif six.PY3 and isinstance(literal, _ast.Bytes):
-            return literal.s
+        elif six.PY3 and isinstance(literal, ast.Bytes):
+            literal_value = literal.s
 
         else:
-            return None
+            literal_value = None
+
+        return literal_value
 
     def get_call_arg_value(self, argument_name):
         '''Gets the value of a named argument in a function call.
@@ -288,9 +276,10 @@ class Context():
         :param argument_name: A string - name of the argument to look for
         :return: Integer - the line number of the found argument, or -1
         '''
-        for key in self.node.keywords:
-            if key.arg == argument_name:
-                return key.value.lineno
+        if hasattr(self.node, 'keywords'):
+            for key in self.node.keywords:
+                if key.arg == argument_name:
+                    return key.value.lineno
 
     def get_call_arg_at_position(self, position_num):
         '''Returns positional argument at the specified position (if it exists)
@@ -298,11 +287,8 @@ class Context():
         :param position_num: The index of the argument to return the value for
         :return: Value of the argument at the specified position if it exists
         '''
-        if (
-            'call' in self._context and
-            hasattr(self._context['call'], 'args') and
-            position_num < len(self._context['call'].args)
-        ):
+        max_args = self.call_args_count
+        if max_args and position_num < max_args:
             return self._get_literal_value(
                 self._context['call'].args[position_num]
             )
@@ -315,10 +301,7 @@ class Context():
         :param module: The module name to look for
         :return: True if the module is found, False otherwise
         '''
-        if 'module' in self._context and self._context['module'] == module:
-            return True
-        else:
-            return False
+        return self._context.get('module') == module
 
     def is_module_imported_exact(self, module):
         '''Check if a specified module has been imported; only exact matches.
@@ -326,10 +309,7 @@ class Context():
         :param module: The module name to look for
         :return: True if the module is found, False otherwise
         '''
-        if 'imports' in self._context and module in self._context['imports']:
-            return True
-        else:
-            return False
+        return module in self._context.get('imports', [])
 
     def is_module_imported_like(self, module):
         '''Check if a specified module has been imported
